Record

Struct Record 

pub struct Record<'a> { /* private fields */ }
An immutable reference to a TableGen record.

This reference cannot outlive the RecordKeeper from which it is borrowed.

Implementations

Source

impl<'a> Record<'a>

pub unsafe fn from_raw(ptr: TableGenRecordRef) -> Record<'a>

Creates a record from a raw object.

Safety

The raw object must be valid.

pub fn name(self) -> Result<&'a str, Error>

Returns the name of the record.

Errors

Returns an error if the name is not a valid UTF-8 string.

pub fn bits_value(self, name: &str) -> Result<Vec<bool>, Error>

Returns the field with the given name converted to a Vec<bool> if this field is of type BitsInit.

pub fn code_value(self, name: &str) -> Result<String, Error>

Returns the field with the given name converted to a String if this field is of type StringInit.

Note that this copies the string into a new string.

pub fn code_str_value(self, name: &str) -> Result<&'a str, Error>

Returns the field with the given name converted to a &str if this field is of type StringInit.

pub fn string_value(self, name: &str) -> Result<String, Error>

Returns the field with the given name converted to a String if this field is of type StringInit.

Note that this copies the string into a new string.

pub fn value<'n>(self, name: &'n str) -> Result<RecordValue<'a>, Error>

Returns a RecordValue for the field with the given name.

pub fn anonymous(self) -> bool

Returns true if the record is anonymous.

pub fn subclass_of(self, class: &str) -> bool

Returns true if the record is a subclass of the class with the given name.

pub fn values(self) -> RecordValueIter<'a>

Returns an iterator over the fields of the record.

The iterator yields RecordValue structs

pub fn has_field(self, name: &str) -> bool

Returns true if the record has a field with the given name.

pub fn field_type(self, name: &str) -> Option<Type>

Returns the TableGenRecTyKind of the field with the given name, or None if the field does not exist.

pub fn dump(self)

Dumps the record to stderr (for debugging).

pub fn num_template_args(self) -> usize

Returns the number of template arguments.

pub fn template_arg_name(self, index: usize) -> Option<&'a str>

Returns the template argument name at the given index.

pub fn template_args(self) -> TemplateArgIter<'a>

Returns an iterator over the template argument names.

pub fn num_super_classes(self) -> usize

Returns the number of direct super classes.

pub fn super_class(self, index: usize) -> Option<Record<'a>>

Returns the super class at the given index.

pub fn direct_super_classes(self) -> SuperClassIter<'a>

Returns an iterator over the direct super classes.

pub fn int_value(self, name: &str) -> Result<i64, Error>

Returns the integer value of the field with the given name.

pub fn str_value(self, name: &str) -> Result<&'a str, Error>

Returns the string value of the field with the given name as a &str.

pub fn bit_value(self, name: &str) -> Result<bool, Error>

Returns the bit (boolean) value of the field with the given name.

pub fn def_value(self, name: &str) -> Result<Record<'a>, Error>

Returns the def value of the field with the given name as a Record.

pub fn dag_value(self, name: &str) -> Result<DagInit<'a>, Error>

Returns the dag value of the field with the given name.

pub fn bits_init_value(self, name: &str) -> Result<BitsInit<'a>, Error>

Returns the bits init of the field with the given name.

pub fn list_init_value(self, name: &str) -> Result<ListInit<'a>, Error>

Returns the list init of the field with the given name.

pub fn list_of_defs_value(self, name: &str) -> Result<Vec<Record<'a>>, Error>

Returns the list-of-defs value of the field with the given name.

pub fn list_of_ints_value(self, name: &str) -> Result<Vec<i64>, Error>

Returns the list-of-ints value of the field with the given name.

pub fn list_of_strings_value(self, name: &str) -> Result<Vec<&'a str>, Error>

Returns the list-of-strings value of the field with the given name.

pub fn optional_str_value(self, name: &str) -> Result<Option<&'a str>, Error>

Returns the optional string value of the field, or None if unset.

Returns Err if the field does not exist or is not a string/unset.

pub fn optional_def_value(self, name: &str) -> Option<Record<'a>>

Returns the optional def value of the field, or None if unset.

pub fn is_value_unset(self, name: &str) -> bool

Returns true if the named field exists and has an unset value (?).

pub fn is_class(self) -> bool

Returns true if this record is a class definition (not a def).

pub fn def_init(self) -> DefInit<'a>

Returns the DefInit for this record.

pub fn id(self) -> u32

Returns the unique numeric ID of this record.

pub fn name_init(self) -> TypedInit<'a>

Returns the name as a raw TypedInit.

pub fn has_direct_super_class(self, super_class: Record<'a>) -> bool

Returns true if the given record is a direct superclass of this record.

pub fn num_type_classes(self) -> usize

Returns the number of classes in this record’s type.

pub fn type_class(self, index: usize) -> Option<Record<'a>>

Returns the class at the given index in this record’s type.

pub fn type_is_subclass_of(self, class: Record<'a>) -> bool

Returns true if this record’s type is a subclass of the given class.